@@ -8,11 +8,13 @@ use warnings;
 
 use Carp;
 
-our $VERSION = 0.06; 
+our $VERSION = 0.07; 
 
 require XSLoader;
 XSLoader::load( __PACKAGE__, $VERSION );
 
+our %HASH = ();
+
 sub import {
 	shift;
 	my @syms = @_;
@@ -25,6 +27,11 @@ sub import {
 	   
 	croak "Unrecognised import symbols @{[ keys %syms ]}" if keys %syms;
 
+	do {
+		no strict 'refs';
+		*{caller() . "::HASH"} = \%{Syntax::Keyword::Combine::Keys::HASH};
+	};
+
 	1;
 }
 
@@ -36,7 +43,7 @@ Syntax::Keyword::Combine::Keys - ckeys keyword
 
 =head1 VERSION
 
-Version 0.05
+Version 0.07
 
 =cut
 
